| Type: | Package |
| Title: | Objects for Predicting Energy Expenditure |
| Version: | 0.1.1 |
| Description: | This is a data-only package containing model objects that predict human energy expenditure from wearable sensor data. Supported methods include the neural networks of Montoye et al. (2017) <doi:10.1080/1091367X.2017.1337638> and the models of Staudenmayer et al. (2015) <doi:10.1152/japplphysiol.00026.2015>, one a linear model and the other a random forest. The package is intended as a spoke for the hub-package 'accelEE', which brings together the above methods and others from packages such as 'Sojourn' and 'TwoRegression.' |
| License: | MIT + file LICENSE |
| Encoding: | UTF-8 |
| LazyData: | true |
| LazyDataCompression: | xz |
| Suggests: | nnet, randomForest |
| Depends: | R (≥ 2.10) |
| RoxygenNote: | 7.3.3 |
| NeedsCompilation: | no |
| Packaged: | 2026-03-28 11:20:13 UTC; phibbing |
| Author: | Paul R. Hibbing [aut, cre], Alexander H.K. Montoye [ctb], John Staudenmayer [ctb], Children's Mercy Kansas City [cph] |
| Maintainer: | Paul R. Hibbing <paulhibbing@gmail.com> |
| Repository: | CRAN |
| Date/Publication: | 2026-04-01 08:50:16 UTC |
EE.Data: Objects for predicting energy expenditure
Description
Contains modeling objects that are useful for predicting energy expenditure from wearable sensor data.
Author(s)
Maintainer: Paul R. Hibbing paulhibbing@gmail.com
Other contributors:
Alexander H.K. Montoye alexander.montoye@montcalm.edu [contributor]
John Staudenmayer jstauden@math.umass.edu [contributor]
Children's Mercy Kansas City [copyright holder]
References
doi:10.1080/1091367X.2017.1337638 doi:10.1152/japplphysiol.00026.2015
Neural networks for energy expenditure prediction
Description
Neural networks for energy expenditure prediction
Usage
montoye_lw
montoye_rw
Format
Objects of class "nnet"
An object of class nnet.formula (inherits from nnet) of length 7.
References
doi:10.1080/1091367X.2017.1337638
Linear model and random forest for energy expenditure prediction
Description
Linear model and random forest for energy expenditure prediction
Usage
staudenmayer_lm
staudenmayer_rf
Format
Two objects, one of class "lm" (staudenmayer_lm) and the
other of class "randomForest" (staudenmayer_rf)
An object of class randomForest.formula (inherits from randomForest) of length 4.