| Title: | Objects for Predicting Energy Expenditure |
|---|---|
| Description: | This is a data-only package containing model objects that predict human energy expenditure from wearable sensor data. Supported methods include the neural networks of Montoye et al. (2017) <doi:10.1080/1091367X.2017.1337638> and the models of Staudenmayer et al. (2015) <doi:10.1152/japplphysiol.00026.2015>, one a linear model and the other a random forest. The package is intended as a spoke for the hub-package 'accelEE', which brings together the above methods and others from packages such as 'Sojourn' and 'TwoRegression.' |
| Authors: | Paul R. Hibbing [aut, cre], Alexander H.K. Montoye [ctb], John Staudenmayer [ctb], Children's Mercy Kansas City [cph] |
| Maintainer: | Paul R. Hibbing <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 0.1.1 |
| Built: | 2026-05-22 09:56:15 UTC |
| Source: | https://github.com/paulhibbing/ee.data |
Neural networks for energy expenditure prediction
montoye_lw montoye_rwmontoye_lw montoye_rw
Objects of class "nnet"
An object of class nnet.formula (inherits from nnet) of length 7.
doi:10.1080/1091367X.2017.1337638
Linear model and random forest for energy expenditure prediction
staudenmayer_lm staudenmayer_rfstaudenmayer_lm staudenmayer_rf
Two objects, one of class "lm" (staudenmayer_lm) and the
other of class "randomForest" (staudenmayer_rf)
An object of class randomForest.formula (inherits from randomForest) of length 4.
doi:10.1152/japplphysiol.00026.2015